@@ -1,15 +1,7 @@
 /*
- * Copyright (C) 2009,2010,2012,2013,2014,2015,2016 Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2009, 2010, 2012, 2013, 2014, 2015, 2016 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "caff.h"
 #include "caff_p.h"
@@ -147,7 +139,7 @@ KGpgCaffPrivate::abortOperation(int result)
 	qCDebug(KGPG_LOG_GENERAL) << "transaction" << sender() << "failed, result" << result;
 	m_tempdir.reset();
 
-	emit q->aborted();
+	Q_EMIT q->aborted();
 }
 
 void
@@ -194,7 +186,7 @@ KGpgCaffPrivate::checkNextLoop()
 					ids.join(QLatin1String("\n")));
 		}
 
-		emit q->done();
+		Q_EMIT q->done();
 	} else {
 		reexportKey(m_allids.first());
 	}
