@@ -1,16 +1,8 @@
 /*
- * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2007,2008,2009,2010,2011 Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2002 Jean-Baptiste Mardelle <bj@altern.org>
+    SPDX-FileCopyrightText: 2007, 2008, 2009, 2010, 2011 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgpgeditor.h"
 
@@ -351,7 +343,7 @@ bool KgpgEditor::slotFileSaveAs()
 			}
 			f.close();
 		} else {
-			auto statJob = KIO::stat(url, KIO::StatJob::DestinationSide, 0);
+            auto statJob = KIO::statDetails(url, KIO::StatJob::DestinationSide, {});
 			KJobWidgets::setWindow(statJob, this);
 			statJob->exec();
 			if (!statJob->error()) {
@@ -405,7 +397,7 @@ void KgpgEditor::slotFind()
 			m_find->setData(m_editor->toPlainText(), m_editor->textCursor().selectionStart());
 		else
 			m_find->setData(m_editor->toPlainText());
-		connect(m_find, QOverload<const QString&, int, int>::of(&KFind::highlight), m_editor, &KgpgTextEdit::slotHighlightText);
+        connect(m_find, &KFind::textFound, m_editor, &KgpgTextEdit::slotHighlightText);
 		connect(m_find, &KFind::findNext, this, &KgpgEditor::slotFindText);
 	} else {
 		m_find->setPattern(fd->pattern());
