@@ -1,22 +1,9 @@
-/* Copyright 2008,2009,2010,2012,2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
- * Copyright 2013 Thomas Fischer <fischer@unix-ag.uni-kl.de>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+/*
+    SPDX-FileCopyrightText: 2008, 2009, 2010, 2012, 2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2013 Thomas Fischer <fischer@unix-ag.uni-kl.de>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 #include "keylistproxymodel.h"
 #include "model/kgpgitemnode.h"
 #include "kgpgitemmodel.h"
@@ -501,9 +488,9 @@ KeyListProxyModel::setPreviewSize(const int pixel)
 {
 	Q_D(KeyListProxyModel);
 
-	emit layoutAboutToBeChanged();
+	Q_EMIT layoutAboutToBeChanged();
 	d->m_previewsize = pixel;
-	emit layoutChanged();
+	Q_EMIT layoutChanged();
 }
 
 QVariant
