@@ -1,21 +1,8 @@
-/* Copyright 2008,2009,2010,2011,2012,2013,2016,2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+/*
+    SPDX-FileCopyrightText: 2008, 2009, 2010, 2011, 2012, 2013, 2016, 2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 #include "kgpgitemmodel.h"
 
 #include "gpgproc.h"
@@ -414,12 +401,12 @@ KGpgItemModel::setDefaultKey(KGpgKeyNode *def)
 	int lastcol = columnCount(QModelIndex()) - 1;
 	if (odefrow >= 0) {
 		KGpgNode *nd = m_root->getChild(odefrow);
-		emit dataChanged(createIndex(odefrow, 0, nd), createIndex(odefrow, lastcol, nd));
+		Q_EMIT dataChanged(createIndex(odefrow, 0, nd), createIndex(odefrow, lastcol, nd));
 	}
 
 	if (def) {
 		m_default = def->getId();
-		emit dataChanged(createIndex(defrow, 0, def), createIndex(defrow, lastcol, def));
+		Q_EMIT dataChanged(createIndex(defrow, 0, def), createIndex(defrow, lastcol, def));
 	} else {
 		m_default.clear();
 	}
@@ -554,7 +541,7 @@ KGpgItemModel::updateNodeTrustColor(KGpgExpandableNode *node, const KgpgCore::Kg
 		KGpgNode *child = node->getChild(i);
 
 		if (child->getTrust() == trust)
-			emit dataChanged(createIndex(i, KEYCOLUMN_TRUST, child), createIndex(i, KEYCOLUMN_TRUST, child));
+			Q_EMIT dataChanged(createIndex(i, KEYCOLUMN_TRUST, child), createIndex(i, KEYCOLUMN_TRUST, child));
 
 		if (!child->hasChildren())
 			continue;
