@@ -6,7 +6,7 @@
 
 class KGpgAddUidTest : public QObject {
 	Q_OBJECT
-private slots:
+private Q_SLOTS:
 	void init();
 	void testAddUid();
 	void testAddUid_data();
