@@ -1,15 +1,7 @@
 /*
- * Copyright (C) 2010,2011 Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2010, 2011 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KGPGDECRYPT_H
 #define KGPGDECRYPT_H
@@ -76,7 +68,7 @@ protected:
 	QStringList command() const override;
 	bool nextLine(const QString &line) override;
 	void finish() override;
-
+	bool closeInputAfterText() const override;
 
 private:
 	int m_fileIndex;
