@@ -1,15 +1,7 @@
 /*
- * Copyright (C) 2008,2009,2010,2011,2012,2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2008, 2009, 2010, 2011, 2012, 2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgpgtextorfiletransaction.h"
 #include "kgpg_general_debug.h"
@@ -120,10 +112,15 @@ KGpgTextOrFileTransaction::preStart()
 	args << command();
 	// if the input is not stdin set command-fd so GnuPG
 	// can ask if e.g. the file already exists
-	m_closeInput = !args.contains(QLatin1String("--command-fd=0"));
-	if (m_closeInput && (!locfiles.isEmpty() || !m_tempfiles.isEmpty())) {
-		args << QLatin1String("--command-fd=0");
+	bool hasCFd = !args.contains(QLatin1String("--command-fd=0"));
+	if (!locfiles.isEmpty() || !m_tempfiles.isEmpty()) {
+		if (!hasCFd)
+			args << QLatin1String("--command-fd=0");
 		m_closeInput = false;
+	} else if (closeInputAfterText()) {
+		m_closeInput = true;
+	} else {
+		m_closeInput = hasCFd;
 	}
 	if (locfiles.count() + m_tempfiles.count() > 1)
 		args << QLatin1String("--multifile");
